import * as pulumi from "@pulumi/pulumi";
/**
 * The ``mysql.Database`` resource creates and manages a database on a MySQL
 * server.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as mysql from "@pulumi/mysql";
 *
 * const app = new mysql.Database("app", {name: "my_awesome_app"});
 * ```
 *
 * ## Import
 *
 * Databases can be imported using their name, e.g.
 *
 * ```sh
 * $ pulumi import mysql:index/database:Database example my-example-database
 * ```
 */
export declare class Database extends pulumi.CustomResource {
    /**
     * Get an existing Database resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DatabaseState, opts?: pulumi.CustomResourceOptions): Database;
    /**
     * Returns true if the given object is an instance of Database.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Database;
    /**
     * The default character set to use when
     * a table is created without specifying an explicit character set. Defaults
     * to "utf8".
     */
    readonly defaultCharacterSet: pulumi.Output<string | undefined>;
    /**
     * The default collation to use when a table
     * is created without specifying an explicit collation. Defaults to
     * ``utf8GeneralCi``. Each character set has its own set of collations, so
     * changing the character set requires also changing the collation.
     *
     * Note that the defaults for character set and collation above do not respect
     * any defaults set on the MySQL server, so that the configuration can be set
     * appropriately even though this provider cannot see the server-level defaults. If
     * you wish to use the server's defaults you must consult the server's
     * configuration and then set the ``defaultCharacterSet`` and
     * ``defaultCollation`` to match.
     */
    readonly defaultCollation: pulumi.Output<string | undefined>;
    /**
     * The name of the database. This must be unique within
     * a given MySQL server and may or may not be case-sensitive depending on
     * the operating system on which the MySQL server is running.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a Database resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DatabaseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Database resources.
 */
export interface DatabaseState {
    /**
     * The default character set to use when
     * a table is created without specifying an explicit character set. Defaults
     * to "utf8".
     */
    defaultCharacterSet?: pulumi.Input<string>;
    /**
     * The default collation to use when a table
     * is created without specifying an explicit collation. Defaults to
     * ``utf8GeneralCi``. Each character set has its own set of collations, so
     * changing the character set requires also changing the collation.
     *
     * Note that the defaults for character set and collation above do not respect
     * any defaults set on the MySQL server, so that the configuration can be set
     * appropriately even though this provider cannot see the server-level defaults. If
     * you wish to use the server's defaults you must consult the server's
     * configuration and then set the ``defaultCharacterSet`` and
     * ``defaultCollation`` to match.
     */
    defaultCollation?: pulumi.Input<string>;
    /**
     * The name of the database. This must be unique within
     * a given MySQL server and may or may not be case-sensitive depending on
     * the operating system on which the MySQL server is running.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Database resource.
 */
export interface DatabaseArgs {
    /**
     * The default character set to use when
     * a table is created without specifying an explicit character set. Defaults
     * to "utf8".
     */
    defaultCharacterSet?: pulumi.Input<string>;
    /**
     * The default collation to use when a table
     * is created without specifying an explicit collation. Defaults to
     * ``utf8GeneralCi``. Each character set has its own set of collations, so
     * changing the character set requires also changing the collation.
     *
     * Note that the defaults for character set and collation above do not respect
     * any defaults set on the MySQL server, so that the configuration can be set
     * appropriately even though this provider cannot see the server-level defaults. If
     * you wish to use the server's defaults you must consult the server's
     * configuration and then set the ``defaultCharacterSet`` and
     * ``defaultCollation`` to match.
     */
    defaultCollation?: pulumi.Input<string>;
    /**
     * The name of the database. This must be unique within
     * a given MySQL server and may or may not be case-sensitive depending on
     * the operating system on which the MySQL server is running.
     */
    name?: pulumi.Input<string>;
}
